pilas.actores.tortuga.Tortuga

Package pilas :: Package actores :: Module tortuga :: Class Tortuga |
[hide private]
[frames] | no frames]

# Class Tortuga

source code

                   object --+
                            |
    estudiante.Estudiante --+
                            |
                  actor.Actor --+
                                |
                               Tortuga

Representa una tortuga que se puede mover por la pantalla.

Este actor está profundamente inspirado por la tortuga de Logo, creada por Seymour Papert en el año 1967.

Instance Methods | [hide private]
__init__(self, x=0, y=0, dibuja=True) Inicializa la tortuga. | source code
avanzar(self, pasos) Se mueve hacia adelante la cantidad de pasos indicada. | source code
giraderecha(self, delta) Da un giro hacia la derecha de la tortuga. | source code
giraizquierda(self, delta) Realiza un giro hacia la izquierda. | source code
actualizar(self) Actualiza su estado interno. | source code
dibujar_linea_desde_el_punto_anterior(self) Realiza el trazado de una linea desde su posición actual hacia la anterior. | source code
bajalapiz(self) Le indica a la tortuga si debe comenzar a dibujar con cada movimiento. | source code
subelapiz(self) Le indica a la tortuga que deje de dibujar con cada movimiento. | source code
pon_color(self, color) Define el color de trazado cuando comienza a moverse. | source code
crear_poligono(self, lados=4, escala=100, sentido=-1) dibuja un poligono de lados de los lados indicados. | source code
crear_circulo(self, radio=30, sentido=-1) Dibuja un circulo. | source code
av(self, pasos) Se mueve hacia adelante la cantidad de pasos indicada. | source code
gd(self, delta) Da un giro hacia la derecha de la tortuga. | source code
gi(self, delta) Realiza un giro hacia la izquierda. | source code
bl(self) Le indica a la tortuga si debe comenzar a dibujar con cada movimiento. | source code
sl(self) Le indica a la tortuga que deje de dibujar con cada movimiento. | source code
pc(self, color) Define el color de trazado cuando comienza a moverse. | source code
get_color(self) Retorna el color que se utilizará para trazar. | source code
set_color(self, color) Define el color que se utilizará para trazar. | source code
pintar(self, color=None) Pinta todo el fondo de un solo color. | source code
Inherited from `actor.Actor`: `__cmp__`, `__mul__`, `__str__`, `actor_mas_cercano`, `anexar`, `colisiona_con`, `colisiona_con_un_punto`, `decir`, `definir_centro`, `definir_color`, `definir_escala`, `definir_imagen`, `definir_posicion`, `definir_rotacion`, `definir_transparencia`, `destruir`, `dibujar`, `distancia_al_punto`, `distancia_con`, `duplicar`, `eliminar`, `es_fondo`, `esta_fuera_de_la_pantalla`, `get_abajo`, `get_arriba`, `get_derecha`, `get_espejado`, `get_fijo`, `get_imagen`, `get_izquierda`, `get_rotation`, `get_scale`, `get_scale_x`, `get_scale_y`, `get_transparencia`, `get_vx`, `get_vy`, `get_x`, `get_y`, `get_z`, `imitar`, `obtener_alto`, `obtener_ancho`, `obtener_centro`, `obtener_escala`, `obtener_imagen`, `obtener_posicion`, `obtener_rotacion`, `pre_actualizar`, `set_abajo`, `set_arriba`, `set_derecha`, `set_espejado`, `set_fijo`, `set_imagen`, `set_izquierda`, `set_rotation`, `set_scale`, `set_scale_x`, `set_scale_y`, `set_transparencia`, `set_x`, `set_y`, `set_z` Inherited from `actor.Actor` (private): `_eliminar_anexados`, `_interpretar_y_convertir_posicion` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__` Inherited from `estudiante.Estudiante`: `actualizar_comportamientos`, `actualizar_habilidades`, `agregar_habilidad`, `aprender`, `eliminar_comportamientos`, `eliminar_habilidad`, `eliminar_habilidades`, `hacer`, `hacer_luego`, `obtener_habilidad`, `tiene_comportamiento`, `tiene_habilidad` Inherited from `estudiante.Estudiante` (private): `_adoptar_el_siguiente_comportamiento`

Properties | [hide private]
| color Retorna el color que se utilizará para trazar.
Inherited from `actor.Actor`: `abajo`, `alto`, `ancho`, `arriba`, `centro`, `derecha`, `escala`, `escala_x`, `escala_y`, `espejado`, `fijo`, `imagen`, `izquierda`, `rotacion`, `transparencia`, `vx`, `vy`, `x`, `y`, `z` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, x=0, y=0, dibuja=True) (Constructor) | source code
Inicializa la tortuga. :param x: Posición horizontal inicial. :param y: Posición vertical inicial. :param dibuja: Indica si a tortuga dejará marcada una linea al moverse. Overrides: estudiante.Estudiante.__init__

### avanzar(self, pasos) | source code
Se mueve hacia adelante la cantidad de pasos indicada. :param pasos: Los pasos que debe avanzar.

### giraderecha(self, delta) | source code
Da un giro hacia la derecha de la tortuga. :param delta: Los grados que digará en ese sentido.

### giraizquierda(self, delta) | source code
Realiza un giro hacia la izquierda. :param delta: Los grados que digará en ese sentido.

### actualizar(self) | source code
Actualiza su estado interno. Overrides: actor.Actor.actualizar

### crear_poligono(self, lados=4, escala=100, sentido=-1) | source code
dibuja un poligono de lados de los lados indicados. :param lados: La cantidad de lados a dibujar. :param escala: El tamaño del polígono a dibujar. :param sentido: El sentido de dibujado, -1 indica hacia la izquierda y 1 hacia la derecha.

### crear_circulo(self, radio=30, sentido=-1) | source code
Dibuja un circulo. :param radio: El radio que deberá tener el circulo. :param sentido: El sentido de dibujado, -1 indica hacia la izquierda y 1 hacia la derecha.

### av(self, pasos) | source code
Se mueve hacia adelante la cantidad de pasos indicada. :param pasos: Los pasos que debe avanzar.

### gd(self, delta) | source code
Da un giro hacia la derecha de la tortuga. :param delta: Los grados que digará en ese sentido.

### gi(self, delta) | source code
Realiza un giro hacia la izquierda. :param delta: Los grados que digará en ese sentido.

### set_color(self, color) | source code
Define el color que se utilizará para trazar. :param color: El color a utilizar.

### pintar(self, color=None) | source code
Pinta todo el fondo de un solo color. :param color: El color que se utilizará para pintar el fondo.

Property Details | [hide private]

### color Retorna el color que se utilizará para trazar. Get Method: get_color(self) - Retorna el color que se utilizará para trazar. Set Method: set_color(self, color) - Define el color que se utilizará para trazar.